import * as angular from 'angular';

export default class AddContentDetailsFormComponent {
    workflow: any;
    content: any;
    loadingTags: boolean;
    static config = {
        selector: 'addContentDetailsForm',
        template: `
            <div layout="column">
                <md-input-container md-is-error="$ctrl.workflow.hasError('url')">
                    <label>{{::$ctrl.AddContentTranslate.get('add-content-workflow__source-step--url')}}</label>
                    <input ng-model="$ctrl.content.url" name="url" ng-required="true" ng-disabled="$ctrl.workflow.savingAddContent" />
                    <div class="md-errors-spacer"></div>
                    <div ng-messages="$ctrl.workflow.validationErrors">
                        <div ng-message="url">{{$ctrl.AddContentTranslate.get($ctrl.workflow.validationErrors.url)}}</div>
                    </div>

                </md-input-container>
                <md-input-container ng-if="$ctrl.workflow.shouldHideField('title', $ctrl.content.mediaType)" md-is-error="$ctrl.workflow.hasError('title')">
                    <label>{{::$ctrl.AddContentTranslate.get('add-content-workflow__details-step--title-label')}}</label>
                    <input ng-model="$ctrl.content.title" name="title" ng-required="$ctrl.workflow.isFieldRequired('title', $ctrl.content.mediaType)" ng-disabled="$ctrl.workflow.savingAddContent" maxlength="140" md-maxlength="140" />
                    <div class="md-errors-spacer"></div>
                    <div ng-messages="$ctrl.workflow.validationErrors">
                        <div ng-message="title">{{$ctrl.AddContentTranslate.get($ctrl.workflow.validationErrors.title)}}</div>
                    </div>
                </md-input-container>
                <md-input-container md-is-error="$ctrl.workflow.hasError('description')">
                    <label>{{$ctrl.AddContentTranslate.get($ctrl.workflow.getLabelAlias('description', $ctrl.content.mediaType) || 'add-content-workflow__details-step--description-label')}}</label>
                    <textarea ng-model="$ctrl.content.description" md-maxlength="1000" maxlength="1000" rows="1" md-select-on-focus="" ng-required="$ctrl.workflow.isFieldRequired('description', $ctrl.content.mediaType)" ng-disabled="$ctrl.workflow.savingAddContent"></textarea>
                    <div class="md-errors-spacer"></div>
                    <div ng-messages="$ctrl.workflow.validationErrors">
                        <div ng-message="description">{{$ctrl.AddContentTranslate.get($ctrl.workflow.validationErrors.description)}}</div>
                    </div>
                </md-input-container>
                <div layout="row">
                    <md-input-container flex style="margin-right:36px;" md-is-error="$ctrl.workflow.hasError('imageUrl')">
                        <label>{{::$ctrl.AddContentTranslate.get('add-content-workflow__details-step--image-url-label')}}</label>
                        <input ng-model="$ctrl.content.imageUrl" name="imageUrl" ng-disabled="$ctrl.workflow.savingAddContent" />
                        <div class="md-errors-spacer"></div>
                        <div ng-messages="$ctrl.workflow.validationErrors">
                            <div ng-message="imageUrl">{{$ctrl.AddContentTranslate.get($ctrl.workflow.validationErrors.imageUrl)}}</div>
                        </div>
                    </md-input-container>
                    <md-input-container flex md-is-error="$ctrl.workflow.hasError('author')">
                        <label>{{$ctrl.AddContentTranslate.get($ctrl.workflow.getLabelAlias('author', $ctrl.content.mediaType) || 'add-content-workflow__details-step--author-label')}}</label>
                        <input 
                            name="author" 
                            ng-model="$ctrl.content.author" 
                            ng-required="$ctrl.workflow.isFieldRequired('author', $ctrl.content.mediaType)" 
                            ng-disabled="$ctrl.workflow.savingAddContent"/>
                        <div class="md-errors-spacer"></div>
                        <div ng-messages="$ctrl.workflow.validationErrors">
                          <div ng-message="author">{{$ctrl.AddContentTranslate.get($ctrl.workflow.validationErrors.author)}}</div>
                        </div>
                    </md-input-container>
                </div>
                <div layout="row">
                    <md-input-container ng-if="$ctrl.workflow.shouldHideField('source', $ctrl.content.mediaType)" flex style="margin-right:36px;"  md-is-error="$ctrl.workflow.hasError('source')">
                        <label>{{::$ctrl.AddContentTranslate.get('add-content-workflow__details-step--source-label')}}</label>
                        <input 
                            name="source" 
                            ng-model="$ctrl.content.publisher" 
                            ng-required="$ctrl.workflow.isFieldRequired('source', $ctrl.content.mediaType)" 
                            ng-disabled="$ctrl.workflow.savingAddContent"/>
                        <div class="md-errors-spacer"></div>
                        <div ng-messages="$ctrl.workflow.validationErrors">
                          <div ng-message="source">{{$ctrl.AddContentTranslate.get($ctrl.workflow.validationErrors.source)}}</div>
                        </div>
                    </md-input-container>
                    <md-input-container flex>
                        <label>{{::$ctrl.AddContentTranslate.get('add-content-workflow__details-step--source-country-label')}}</label>
                        <md-select ng-model="$ctrl.content.countryCode" ng-disabled="$ctrl.workflow.savingAddContent">
                            <md-option ng-repeat="country in $ctrl.workflow.countries" ng-value="country.code">{{$ctrl.AddContentTranslate.get(country.name)}}</md-option>
                        </md-select>
                        <div class="md-errors-spacer"></div>
                    </md-input-container>
                </div>
                <div layout="row">
                    <md-input-container flex>
                        <label>{{$ctrl.AddContentTranslate.get($ctrl.workflow.getLabelAlias('publishDate', $ctrl.content.mediaType) || 'add-content-workflow__details-step--publish-date-label')}}</label>
                        <mw-date-picker-dropdown
                            form-input-name="$ctrl.workflow.datepicker.formInputName"
                            is-required="true"
                            date="$ctrl.content.date"
                            locale="$ctrl.workflow.datePicker.locale"
                            min-view="$ctrl.workflow.datePicker.minView"
                            max-view="$ctrl.workflow.datePicker.maxView"
                            max-date="$ctrl.workflow.datePicker.maxDate"
                            label="$ctrl.workflow.datePicker.label"
                            format="$ctrl.workflow.datePicker.format"
                            timezone="$ctrl.workflow.datePicker.timezone"
                            on-date-selection="$ctrl.onDateChange($event)"
                            disabled="$ctrl.workflow.savingAddContent"
                        > 
                        </mw-date-picker-dropdown>
                    </md-input-container>
                </div>
                <div layout="column">
                    <label class="mw-active-label">{{::$ctrl.AddContentTranslate.get('add-content-workflow__details-step--tags-label')}}</label>
                    <md-button 
                        class="mw-button mw-button--outlined mw-button--no-margin" 
                        ng-click="$ctrl.showTagSelectModal($event)" 
                        ng-disabled="$ctrl.loadingTags || $ctrl.workflow.savingAddContent" 
                        style="margin: 8px 0"
                    >
                        <md-progress-circular ng-if="$ctrl.loadingTags"
                            md-diameter="16px"
                            style="margin: 8px auto"></md-progress-circular>
                        <span ng-if="!$ctrl.loadingTags">{{::$ctrl.AddContentTranslate.get('add-content-workflow__details-step--add-tags-button')}}</span>
                    </md-button>
                    <div class="add-content-wafer" ng-repeat="tag in $ctrl.content.tags" ng-if="tag.selected" layout="row" layout-align="start center">
                        <mw-icon class="add-content-wafer__icon" svg-icon="meltwater:tag-on"></mw-icon>
                        <div class="add-content-wafer__content" flex>
                            {{tag.display}}
                        </div>
                        <mw-icon-button
                            svg-icon="navigation:ic_close_24px"
                            class="md-icon-button"
                            ng-click="::$ctrl.deselectTag($index)"
                            size="sm"
                            tooltip="{{::$ctrl.AddContentTranslate.get('add-content-workflow__details-step--tag-remove-tooltip')}}"
                            hover="true"
                            ng-disabled="$ctrl.workflow.savingAddContent">
                        </mw-icon-button>
                    </div>
                </div>
            </div>
        `,
        controller: AddContentDetailsFormComponent,
        bindings: {
            workflow: '<',
            content: '<'
        }
    };

    /*@ngInject*/
    constructor(
        private $mdDialog,
        private AddContentTagService,
        private AddContentTranslate
    ) {
    }

    $onInit() {
        this.content.tags = [];
        this.loadingTags = true;
        this.AddContentTagService.getTagsAndFilterForPersonalization(this.workflow.userObject.activeCompanyId, this.workflow.userObject._id, this.workflow.preSelectedTags)
            .then(tagList => {
                this.content.tags = tagList.map(tag => {
                    return {
                        display: tag.name,
                        type: 'tag',
                        id: tag.id,
                        selected: this.workflow.preSelectedTags.indexOf(tag.name) >= 0
                    }
                })
                .sort((tagA, tagB) => {
                    if(tagA.display.toLowerCase() > tagB.display.toLowerCase()) {
                        return 1;
                    }
                    if(tagA.display.toLowerCase() < tagB.display.toLowerCase()) {
                        return -1;
                    }
                    return 0;
                });
                this.loadingTags = false;
            })
            .catch(error => {
                if (error) {
                    console.error('Failed to load tags from document modification service', error);
                }
            });
  
    }

    onDateChange = ($ev) => {
        this.content.date = $ev.date;
    };

    deselectTag = (tagIndex) => {
      this.content.tags[tagIndex].selected = false;
    };

    showTagSelectModal = (event) => {
        const parent = angular.element(document.getElementsByClassName('md-dialog-container')[0]);

        this.$mdDialog.show({
            parent,
            multiple: true,
            autoWrap: false,
            bindToController: true,
            fullscreen: true,
            targetEvent: event,
            locals: {
                inputs: angular.copy(this.content.tags)
            },
            template: `
                <md-dialog class="mw-mini-modal mw-mini-modal--maximized" aria-label="" layout="column">
                    <input-selector-dialog class="mw-mini-modal-wrapper" inputs="$ctrl.inputs" layout="column"></input-selector-dialog>
                </md-dialog>
            `,
            controller: 'MwMiniModalDialogController',
            controllerAs: '$ctrl',
        })
            .then(
                (inputs) => {
                    this.content.tags = inputs;
                }
            )
            .catch(error => {
                if (error) {
                    console.error('Error applying tags to add content', error);
                }
            });
    };
}
